@@ -1,4 +1,30 @@
-/* -*- c++ -*- (enables emacs c++ mode)                                    */
+// -*- c++ -*- (enables emacs c++ mode)
+//========================================================================
+//
+// Copyright (C) 2000-2006 Julien Pommier
+//
+// This file is a part of GETFEM++
+//
+// Getfem++ is free software; you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as
+// published by the Free Software Foundation; version 2.1 of the License.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+// You should have received a copy of the GNU Lesser General Public
+// License along with this program; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301,
+// USA.
+//
+//========================================================================
+
+/**@file bgeot_small_vector.h
+   @author  Julien Pommier <Julien.Pommier@insa-toulouse.fr>
+   @date January 2004.
+   @brief Small (dim < 8) vectors.
+*/
 #ifndef BGEOT_SMALL_VECTOR_H
 #define BGEOT_SMALL_VECTOR_H
 
@@ -95,7 +121,7 @@ namespace bgeot {
       }
     }
     /* allocation of a chunk */
-    node_id allocate(size_type n);
+    node_id allocate(block_allocator::size_type n);
     /* deallocation of a chunk */
     void deallocate(node_id nid);
     void memstats();
@@ -106,8 +132,8 @@ namespace bgeot {
       memcpy(obj_data(id2),obj_data(id),obj_sz(id));
       return id2;
     }
-    void insert_block_into_unfilled(size_type bid);
-    void remove_block_from_unfilled(size_type bid);
+    void insert_block_into_unfilled(block_allocator::size_type bid);
+    void remove_block_from_unfilled(block_allocator::size_type bid);
   };
   
   /* common class for all mini_vec, provides access to the common static allocator */
@@ -118,10 +144,9 @@ namespace bgeot {
     static_block_allocator() { if (!palloc) palloc=&dal::singleton<block_allocator,1000>::instance(); } //new block_allocator(); }
   };
   
-  /**
-    small_vector class: container for small vectors of POD types. Should be as fast as 
-    std::vector<T> while beeing smaller and uses copy-on-write. The gain is especially
-    valuable on 64 architectures.
+  /** container for small vectors of POD (Plain Old Data) types. Should be as fast as 
+      std::vector<T> while beeing smaller and uses copy-on-write. The gain is especially
+      valuable on 64 bits architectures.
   */
   template<typename T> class small_vector : public static_block_allocator {
     typedef block_allocator::node_id node_id;
@@ -171,7 +196,14 @@ namespace bgeot {
     explicit small_vector(const std::vector<T>& v) : id(allocate(v.size())) { 
       std::copy(v.begin(),v.end(),begin());
     }
-    ~small_vector() { allocator().dec_ref(id); }
+    ~small_vector() { 
+      // in the wonderful world of static objects, the order of destruction 
+      // can be really important when the memory allocator is destroyed
+      // before , for ex. a global variable of type small_vector...
+      // that's why there is a check on the state of the allocator..
+      if (!allocator_destroyed()) 
+	allocator().dec_ref(id); 
+    }
 
     small_vector(T v1, T v2) : id(allocate(2)) 
     { begin()[0] = v1; begin()[1] = v2; }
@@ -188,6 +220,8 @@ namespace bgeot {
     { return small_vector<T>(*this,other,std::plus<T>()); }
     small_vector<T> operator-(const small_vector<T>& other) const 
     { return small_vector<T>(*this,other,std::minus<T>()); }
+    small_vector<T> operator-() const 
+    { return -1.*(*this); }
     small_vector<T> operator*(T v) const 
     { return small_vector<T>(*this, std::bind2nd(std::multiplies<T>(),v)); }
     small_vector<T> operator/(T v) const { return (*this)*(T(1)/v); }
@@ -222,6 +256,7 @@ namespace bgeot {
       SVEC_ASSERT(id == 0 || refcnt()); return static_cast<pointer>(allocator().obj_data(id)); 
     }
     block_allocator& allocator() const { return *palloc; }
+    bool allocator_destroyed() const { return palloc == 0; }
     node_id allocate(size_type n) {
       return (allocator().allocate(n*sizeof(value_type))); SVEC_ASSERT(refcnt() == 1);
     }
