@@ -1,35 +1,79 @@
-/* -*- c++ -*- (enables emacs c++ mode)                                    */
-/* *********************************************************************** */
-/*                                                                         */
-/* Library :  Basic GEOmetric Tool  (bgeot)                                */
-/* File    :  bgeot_integration.h : exact and approximative integration.   */
-/*                                                                         */
-/* Date : December 17, 2000.                                               */
-/* Author : Yves Renard, Yves.Renard@gmm.insa-tlse.fr                      */
-/*                                                                         */
-/* *********************************************************************** */
-/*                                                                         */
-/* Copyright (C) 2000-2002  Yves Renard.                                   */
-/*                                                                         */
-/* This file is a part of GETFEM++                                         */
-/*                                                                         */
-/* This program is free software; you can redistribute it and/or modify    */
-/* it under the terms of the GNU Lesser General Public License as          */
-/* published by the Free Software Foundation; version 2.1 of the License.  */
-/*                                                                         */
-/* This program is distributed in the hope that it will be useful,         */
-/* but WITHOUT ANY WARRANTY; without even the implied warranty of          */
-/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           */
-/* GNU Lesser General Public License for more details.                     */
-/*                                                                         */
-/* You should have received a copy of the GNU Lesser General Public        */
-/* License along with this program; if not, write to the Free Software     */
-/* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,  */
-/* USA.                                                                    */
-/*                                                                         */
-/* *********************************************************************** */
+// -*- c++ -*- (enables emacs c++ mode)
+//========================================================================
+//
+// Copyright (C) 2000-2006 Yves Renard
+//
+// This file is a part of GETFEM++
+//
+// Getfem++ is free software; you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as
+// published by the Free Software Foundation; version 2.1 of the License.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+// You should have received a copy of the GNU Lesser General Public
+// License along with this program; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301,
+// USA.
+//
+//========================================================================
 
+/**@file getfem_integration.h
+   @author  Yves Renard <Yves.Renard@insa-toulouse.fr>
+   @date December 17, 2000.
+   @brief Integration methods (exact and approximated) on convexes
 
+   @section im_list List of integration methods for getfem::int_method_descriptor
+
+   - "IM_EXACT_SIMPLEX(n)"             : exact integration on simplexes.
+   - "IM_PRODUCT(IM1, IM2)"            : product of two integration methods
+   - "IM_EXACT_PARALLELEPIPED(n)"      : exact integration on parallelepipeds
+   - "IM_EXACT_PRISM(n)"               : exact integration on prisms
+   - "IM_GAUSS1D(K)"                   : Gauss method on the segment, 
+                                         order K=1, 3, 5, 7, ..., 99.
+   - "IM_GAUSSLOBATTO1D(K)"            : Gauss-Lobatto method on the segment, 
+                                         order K=1, 3, 5, 7, ..., 99.
+   - "IM_NC(N,K)"                      : Newton-Cotes approximative 
+                                         integration on simplexes, order K
+   - "IM_NC_PARALLELEPIPED(N,K)"       : product of Newton-Cotes integration 
+                                         on parallelepipeds
+   - "IM_NC_PRISM(N,K)"                : product of Newton-Cotes integration
+                                         on prisms
+   - "IM_GAUSS_PARALLELEPIPED(N,K)"    : product of Gauss1D integration
+                                         on parallelepipeds (K=1,3,..99)
+   - "IM_TRIANGLE(K)"                  : Gauss methods on triangles
+                                         (K=1..10,13,17,19)
+   - "IM_QUAD(K)"                      : Gauss methods on quadrilaterons
+                                         (K=2, 3, 5, 7, 9, 17)
+   - "IM_HEXAHEDRON(K)"                : Gauss methods on hexahedrons
+                                         (K=5,9,11)
+   - "IM_TETRAHEDRON(K)"               : Gauss methods on tetrahedrons
+                                         (K=1, 2, 3, 5, 6, or 8)
+   - "IM_SIMPLEX4D(3)"                 : Gauss method on a 4-dimensional
+                                         simplex.
+   - "IM_CUBE4D(K)"                    : Gauss method on a 4-dimensional cube
+                                         (K=5,9).
+   - "IM_STRUCTURED_COMPOSITE(IM1, K)" : Composite method on a grid with
+                                         K divisions
+   - "IM_HCT_COMPOSITE(IM1)"           : Composite integration suited to the HCT
+                                         composite finite element.
+
+   - "IM_QUASI_POLAR(IM1, IP1)"        : if IM1 is an integration method on a
+               square, gives an integration method on a triangle which is
+	       close to a polar integration with respect to vertex IP1.
+	       if IM1 is an integration method on a tetrahedron, gives an
+	       integration method on a tetrahedron which is close to a
+	       cylindrical integration with respect to vertex IP1 (does not work very well).
+	       if IM1 is an integration method on a prism. Gives an integration
+               method on a tetrahedron which is close to a
+	       cylindrical integration with respect to vertex IP1.
+   - "IM_QUASI_POLAR(IM1, IP1, IP2)"   : IM1 should be an integration method
+               on a prism. Gives an integration method on a tetrahedron which
+	       is close to a cylindrical integration with respect to IP1-IP2
+	       axis.
+*/
 #ifndef GETFEM_INTEGRATION_H__
 #define GETFEM_INTEGRATION_H__
 
@@ -44,8 +88,7 @@ namespace getfem
    *  This class is not to be manipulate by itself. Use ppoly_integration and
    *  the functions written to produce the basic descriptions.
    */
-  class poly_integration
-  {
+  class poly_integration {
     protected :
 
       bgeot::pconvex_structure cvs;
@@ -70,7 +113,8 @@ namespace getfem
       /** Evaluate the integral of the polynomial P on the face f of the
        *    reference element.
        */
-      long_scalar_type int_poly_on_face(const base_poly &P, short_type f) const;
+      long_scalar_type int_poly_on_face(const base_poly &P,
+					short_type f) const;
 
       virtual ~poly_integration() {}
 
@@ -84,11 +128,11 @@ namespace getfem
    *  and the functions written to produce the basic descriptions.
    */
 
-  class integration_method;
-  typedef const integration_method *pintegration_method;
+  class integration_method;  
+  typedef boost::intrusive_ptr<const integration_method> pintegration_method;
 
-  class approx_integration
-  {
+
+  class approx_integration {
     protected :
 
       typedef dal::dynamic_tree_sorted<base_node,
@@ -114,6 +158,8 @@ namespace getfem
       /// Number of integration nodes on the face f of the reference element.
       size_type nb_points_on_face(short_type f) const
       { return repartition[f+1] - repartition[f]; }
+      size_type ind_first_point_on_face(short_type f) const 
+      { return repartition[f]; }
       /// Structure of the reference element.
       bgeot::pconvex_structure structure(void) const
         { return cvr->structure()->basic_structure(); }
@@ -157,7 +203,7 @@ namespace getfem
     
   };
 
-  typedef const approx_integration * papprox_integration;
+  typedef const approx_integration *papprox_integration;
 
   /**
      the list of main integration method types 
@@ -168,21 +214,37 @@ namespace getfem
      this structure is not intended to be used directly. It is built via
      the int_method_descriptor() function
   */
-  class integration_method {    
+  class integration_method : virtual public dal::static_stored_object {    
     union {
       ppoly_integration ppi; /* for exact integrations */
       papprox_integration pai; /* for approximate integrations (i.e. cubatures) */
     } method;
     integration_method_type im_type;
 
+    void remove(void) {
+      switch (type()) {
+      case IM_EXACT: if (method.ppi) delete method.ppi; break;
+      case IM_APPROX: if (method.pai) delete method.pai; break;
+      case IM_NONE: break;
+      }
+    }
+
   public:
     integration_method_type type(void) const { return im_type; }
     papprox_integration approx_method(void) const { return method.pai; }
     ppoly_integration exact_method(void) const { return method.ppi; }
 
+    void set_approx_method(papprox_integration paii)
+    { remove(); method.pai = paii; im_type = IM_APPROX; }
+    void set_exact_method(ppoly_integration ppii)
+    { remove(); method.ppi = ppii; im_type = IM_EXACT; }
+
     const bgeot::stored_point_tab &integration_points(void) const { 
-      if (type() == IM_EXACT)
-	return *(bgeot::org_stored_point_tab(method.ppi->structure()->dim()));
+      if (type() == IM_EXACT) {
+	size_type n = method.ppi->structure()->dim();
+	std::vector<base_node> spt(1); spt[0] = base_node(n);
+	return (*store_point_tab(spt));
+      }
       else if (type() == IM_APPROX)
 	return method.pai->integration_points();
       else DAL_THROW(dal::failure_error, "IM_NONE has no points");
@@ -204,40 +266,23 @@ namespace getfem
     { method.pai = p; im_type = IM_APPROX; }
 
     integration_method(void) { im_type = IM_NONE; method.pai = 0; }
-    ~integration_method(void) {
-      switch (type()) {
-      case IM_EXACT: if (method.ppi) delete method.ppi; break;
-      case IM_APPROX: if (method.pai) delete method.pai; break;
-      case IM_NONE: break;
-      }
-    }
+    ~integration_method(void) { remove(); }
   };
 
 
+  /** Get an integration method from its name 
+      @see @ref im_list 
+  */
   pintegration_method int_method_descriptor(std::string name);
-  /* List :
-   * "IM_EXACT_SIMPLEX(n)"             : exact integration on simplexes.
-   * "IM_PRODUCT(IM1, IM2)"            : product of two integration methods
-   * "IM_EXACT_PARALLELEPIPED(n)"      : exact integration on parallelepipeds
-   * "IM_EXACT_PRISM(n)"               : exact integration on prisms
-   * "IM_GAUSS1D(K)"                   : Gauss method on the segment, order K
-   * "IM_NC(N,K)"                      : Newton-Cotes approximative 
-   *                                     integration on simplexes, order K
-   * "IM_NC_PARALLELEPIPED(N,K)"       : product of Newton-Cotes integration 
-   *                                     on parallelepipeds
-   * "IM_NC_PRISM(N,K)"                : product of Newton-Cotes integration
-   *                                     on prisms
-   * "IM_GAUSS_PARALLELEPIPED(N,K)"    : product of Gauss1D integration
-   *                                     on parallelepipeds
-   * "IM_TRIANGLE(K)"                  : Gauss methods on triangles (K=1..7)
-   * "IM_QUAD(K)"                      : Gauss methods on quadrilaterons
-   *                                     (K=2, 3 or 5)
-   * "IM_TETRAHEDRON(K)"               : Gauss methods on tetrahedrons
-   *                                     (K=1, 2, 3 or 5)
-   * "IM_STRUCTURED_COMPOSITE(IM1, K)" : Composite method on a grid with
-   *                                     K divisions
+
+  /** Get the string name of an integration method .
    */
+  std::string name_of_int_method(pintegration_method p);
   
+  /**
+     return an exact integration method for convex type handled by pgt.
+     If pgt is not linear, classical_exact_im will fail.
+  */
   pintegration_method classical_exact_im(bgeot::pgeometric_trans pgt);
   /**
      try to find an approximate integration method for the geometric
@@ -247,17 +292,27 @@ namespace getfem
   */
   pintegration_method classical_approx_im(bgeot::pgeometric_trans pgt, dim_type degree);
 
+  /// return IM_EXACT_SIMPLEX(n)
   pintegration_method exact_simplex_im(size_type n);
+  /// return IM_EXACT_PARALLELEPIPED(n)
   pintegration_method exact_parallelepiped_im(size_type n);
+  /// return IM_EXACT_PRISM(n)
   pintegration_method exact_prism_im(size_type n);
+  /// use classical_exact_im instead.
   pintegration_method exact_classical_im(bgeot::pgeometric_trans pgt) IS_DEPRECATED;
+  /// return IM_NONE
+  pintegration_method im_none(void);
 
-  std::string name_of_int_method(pintegration_method p);
   class mesh_precomposite;
-  class mesh_fem;
+  class mesh_im;
   papprox_integration composite_approx_int_method(const mesh_precomposite &mp, 
-						  const mesh_fem &mf,
+						  const mesh_im &mf,
 						  bgeot::pconvex_ref cr);
+
+  /* try to integrate all monomials up to order 'order' and return the 
+     max. error */
+  scalar_type test_integration_error(papprox_integration pim, dim_type order);
+
 }  /* end of namespace getfem.                                            */
 
 
