@@ -1,35 +1,24 @@
-/* -*- c++ -*- (enables emacs c++ mode)                                    */
-/* *********************************************************************** */
-/*                                                                         */
-/* Library :  GEneric Tool for Finite Element Methods (getfem)             */
-/* File    :  getfem_norm.h: computes various norms on pde solutions.      */
-/*     									   */
-/* Date : November 17, 2000.                                               */
-/* Authors : Yves Renard, Yves.Renard@gmm.insa-tlse.fr                     */
-/*           Julien Pommier, pommier@gmm.insa-tlse.fr                      */
-/*                                                                         */
-/* *********************************************************************** */
-/*                                                                         */
-/* Copyright (C) 2000-2002  Yves Renard.                                   */
-/*                                                                         */
-/* This file is a part of GETFEM++                                         */
-/*                                                                         */
-/* This program is free software; you can redistribute it and/or modify    */
-/* it under the terms of the GNU Lesser General Public License as          */
-/* published by the Free Software Foundation; version 2.1 of the License.  */
-/*                                                                         */
-/* This program is distributed in the hope that it will be useful,         */
-/* but WITHOUT ANY WARRANTY; without even the implied warranty of          */
-/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           */
-/* GNU Lesser General Public License for more details.                     */
-/*                                                                         */
-/* You should have received a copy of the GNU Lesser General Public        */
-/* License along with this program; if not, write to the Free Software     */
-/* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,  */
-/* USA.                                                                    */
-/*                                                                         */
-/* *********************************************************************** */
- 
+// -*- c++ -*- (enables emacs c++ mode)
+//========================================================================
+//
+// Copyright (C) 2000-2006 Yves Renard
+//
+// This file is a part of GETFEM++
+//
+// Getfem++ is free software; you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as
+// published by the Free Software Foundation; version 2.1 of the License.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+// You should have received a copy of the GNU Lesser General Public
+// License along with this program; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301,
+// USA.
+//
+//========================================================================
 
 #ifndef GETFEM_NORM_H__
 #define GETFEM_NORM_H__
@@ -72,8 +61,8 @@ namespace getfem
     }
     /*virtual*/ void intersection_callback(mesh_slicer &ms, size_type slmcv) {
       if (ms.splx_in.card() == 0) return;
-      const getfem_mesh &m1 = mf1.linked_mesh();
-      const getfem_mesh &m2 = mf2.linked_mesh();
+      const mesh &m1 = mf1.linked_mesh();
+      const mesh &m2 = mf2.linked_mesh();
       bgeot::pgeometric_trans pgt1 = m1.trans_of_convex(ms.cv);
       bgeot::pgeometric_trans pgt2 = m2.trans_of_convex(slmcv);
       pfem pf1 = mf1.fem_of_element(ms.cv); 
@@ -91,7 +80,7 @@ namespace getfem
       /* coordinates on the ref convex of each mesh */
       std::vector<base_node> nodes1(im->nb_points_on_convex()), 
 	nodes2(im->nb_points_on_convex());
-      gti.init(m2.convex(slmcv), pgt2);
+      gti.init(m2.convex(slmcv).points(), pgt2);
       //cout << "hello, doing cv " << ms.cv << " <-> " << slmcv << " [" << ms.splx_in.card() << " simplexes]\n";
       for (dal::bv_visitor is(ms.splx_in); !is.finished(); ++is) {
 	const slice_simplex &s = ms.simplexes[is];
@@ -104,7 +93,7 @@ namespace getfem
 	  for (size_type j=0; j < s.dim(); ++j)
 	    M(i,j) = ms.nodes[s.inodes[i+1]].pt[j] - ms.nodes[s.inodes[0]].pt[j];
 	
-	scalar_type J = dal::abs(gmm::lu_det(M));
+	scalar_type J = gmm::abs(gmm::lu_det(M));
 	
 	/* build nodes1 and nodes2 */
 	std::vector<base_node> ptref(s.dim()+1);
@@ -131,17 +120,17 @@ namespace getfem
 	    pf1->interpolation(ctx1, coeff1, val1, qdim);
 	    pf2->interpolation(ctx2, coeff2, val2, qdim);
 	    for (size_type q=0; q < qdim; ++q) {
-	      l2_norm_sqr += dal::sqr(val1[q]-val2[q])*J*im->coeff(i);
-	      linf_norm = std::max(linf_norm, dal::abs(val1[q]-val2[q]));
+	      l2_norm_sqr += gmm::sqr(val1[q]-val2[q])*J*im->coeff(i);
+	      linf_norm = std::max(linf_norm, gmm::abs(val1[q]-val2[q]));
 	    }
 	  }
 	  if (what & H1_SEMI_NORM) {
 	    pf1->interpolation_grad(ctx1, coeff1, gval1, qdim);
 	    pf2->interpolation_grad(ctx2, coeff2, gval2, qdim);
 	    for (size_type q=0; q < qdim*mdim; ++q) {
-	      scalar_type v = dal::sqr(gval1[q]-gval2[q])*J*im->coeff(i);
+	      scalar_type v = gmm::sqr(gval1[q]-gval2[q])*J*im->coeff(i);
 	      if (v > maxd) { cout << "new maxd: " << v << ", J=" << J << " at " << ctx1.xreal() << ", " << ctx2.xreal() << ", v1=" << gval1[q] << ", v2=" << gval2[q] << "\n"; maxd = v; }
-	      h1_semi_norm_sqr += dal::sqr(gval1[q]-gval2[q])*J*im->coeff(i);
+	      h1_semi_norm_sqr += gmm::sqr(gval1[q]-gval2[q])*J*im->coeff(i);
 	    }
 	  }
 	}
