@@ -1,33 +1,30 @@
-/* -*- c++ -*- (enables emacs c++ mode)                                    */
-/* *********************************************************************** */
-/*                                                                         */
-/* Library :  Generic Matrix Methods  (gmm)                                */
-/* File    :  gmm_sub_vector.h : generic sub matrices.                     */
-/*     									   */
-/* Date : October 13, 2002.                                                */
-/* Author : Yves Renard, Yves.Renard@gmm.insa-tlse.fr                      */
-/*                                                                         */
-/* *********************************************************************** */
-/*                                                                         */
-/* Copyright (C) 2002  Yves Renard.                                        */
-/*                                                                         */
-/* This file is a part of GMM++                                            */
-/*                                                                         */
-/* This program is free software; you can redistribute it and/or modify    */
-/* it under the terms of the GNU Lesser General Public License as          */
-/* published by the Free Software Foundation; version 2.1 of the License.  */
-/*                                                                         */
-/* This program is distributed in the hope that it will be useful,         */
-/* but WITHOUT ANY WARRANTY; without even the implied warranty of          */
-/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           */
-/* GNU Lesser General Public License for more details.                     */
-/*                                                                         */
-/* You should have received a copy of the GNU Lesser General Public        */
-/* License along with this program; if not, write to the Free Software     */
-/* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,  */
-/* USA.                                                                    */
-/*                                                                         */
-/* *********************************************************************** */
+// -*- c++ -*- (enables emacs c++ mode)
+//========================================================================
+//
+// Copyright (C) 2002-2006 Yves Renard
+//
+// This file is a part of GETFEM++
+//
+// Getfem++ is free software; you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as
+// published by the Free Software Foundation; version 2.1 of the License.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+// You should have received a copy of the GNU Lesser General Public
+// License along with this program; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301,
+// USA.
+//
+//========================================================================
+
+/**@file gmm_sub_matrix.h
+   @author  Yves Renard <Yves.Renard@insa-toulouse.fr>
+   @date October 13, 2002.
+   @brief Generic sub-matrices.
+*/
 
 #ifndef GMM_SUB_MATRIX_H__
 #define GMM_SUB_MATRIX_H__
@@ -151,6 +148,7 @@ namespace gmm {
     typedef typename linalg_traits<const_sub_row_type>::storage_type
             storage_type;
     typedef row_major sub_orientation;
+    typedef linalg_true index_sorted;
     static size_type nrows(const this_type &m) { return m.nrows(); }
     static size_type ncols(const this_type &m) { return m.ncols(); }
     static const_sub_row_type row(const const_row_iterator &it)
@@ -295,6 +293,7 @@ namespace gmm {
 	    gen_sub_col_matrix_iterator<PT, SUBI1, SUBI2>, PT>::ref_type
             col_iterator;
     typedef col_major sub_orientation;
+    typedef linalg_true index_sorted;
     typedef typename linalg_traits<const_sub_col_type>::storage_type
     storage_type;
     static size_type nrows(const this_type &m) { return m.nrows(); }
@@ -407,6 +406,9 @@ namespace gmm {
   }
   
 
+
+
+
 }
 
 #endif //  GMM_SUB_MATRIX_H__
