@@ -1,33 +1,30 @@
-/* -*- c++ -*- (enables emacs c++ mode)                                    */
-/* *********************************************************************** */
-/*                                                                         */
-/* Library :  Generic Matrix Methods  (gmm)                                */
-/* File    :  gmm_sub_vector.h : generic sub vectors.                      */
-/*     									   */
-/* Date : October 13, 2002.                                                */
-/* Author : Yves Renard, Yves.Renard@gmm.insa-tlse.fr                      */
-/*                                                                         */
-/* *********************************************************************** */
-/*                                                                         */
-/* Copyright (C) 2002-2003  Yves Renard.                                   */
-/*                                                                         */
-/* This file is a part of GMM++                                            */
-/*                                                                         */
-/* This program is free software; you can redistribute it and/or modify    */
-/* it under the terms of the GNU Lesser General Public License as          */
-/* published by the Free Software Foundation; version 2.1 of the License.  */
-/*                                                                         */
-/* This program is distributed in the hope that it will be useful,         */
-/* but WITHOUT ANY WARRANTY; without even the implied warranty of          */
-/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           */
-/* GNU Lesser General Public License for more details.                     */
-/*                                                                         */
-/* You should have received a copy of the GNU Lesser General Public        */
-/* License along with this program; if not, write to the Free Software     */
-/* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,  */
-/* USA.                                                                    */
-/*                                                                         */
-/* *********************************************************************** */
+// -*- c++ -*- (enables emacs c++ mode)
+//========================================================================
+//
+// Copyright (C) 2002-2006 Yves Renard
+//
+// This file is a part of GETFEM++
+//
+// Getfem++ is free software; you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as
+// published by the Free Software Foundation; version 2.1 of the License.
+//
+// This program is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU Lesser General Public License for more details.
+// You should have received a copy of the GNU Lesser General Public
+// License along with this program; if not, write to the Free Software
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301,
+// USA.
+//
+//========================================================================
+
+/**@file gmm_sub_vector.h
+   @author  Yves Renard <Yves.Renard@insa-toulouse.fr>
+   @date October 13, 2002.
+   @brief Generic sub-vectors.
+*/
 
 #ifndef GMM_SUB_VECTOR_H__
 #define GMM_SUB_VECTOR_H__
@@ -165,6 +162,8 @@ namespace gmm {
     typedef this_type * pthis_type;
     typedef PT pV;
     typedef typename std::iterator_traits<PT>::value_type V;
+    typedef typename linalg_and<typename index_is_sorted<SUBI>::bool_type,
+	    typename linalg_traits<V>::index_sorted>::bool_type index_sorted;
     typedef typename linalg_traits<V>::is_reference V_reference;
     typedef typename linalg_traits<V>::origin_type origin_type;
     typedef typename select_ref<const origin_type *, origin_type *,
@@ -407,6 +406,7 @@ namespace gmm {
     typedef skyline_sub_vector_iterator<const_V_iterator, pre_iterator, SUBI>
             const_iterator;
     typedef abstract_skyline storage_type;
+    typedef linalg_true index_sorted;
     static size_type size(const this_type &v) { return v.size(); }
     static iterator begin(this_type &v) {
       iterator it;
@@ -470,6 +470,14 @@ namespace gmm {
       sub_index::const_iterator, V> vector_type;
   }; 
 
+  template <typename PT>
+  struct svrt_ir<PT, unsorted_sub_index, abstract_dense> {
+    typedef typename std::iterator_traits<PT>::value_type V;
+    typedef typename vect_ref_type<PT,  V>::iterator iterator;
+    typedef tab_ref_index_ref_with_origin<iterator,
+      unsorted_sub_index::const_iterator, V> vector_type;
+  }; 
+
   template <typename PT>
   struct svrt_ir<PT, sub_interval, abstract_dense> {
     typedef typename std::iterator_traits<PT>::value_type V;
@@ -494,6 +502,11 @@ namespace gmm {
     typedef sparse_sub_vector<PT, sub_index> vector_type;
   };
 
+  template <typename PT>
+  struct svrt_ir<PT, unsorted_sub_index, abstract_skyline> {
+    typedef sparse_sub_vector<PT, unsorted_sub_index> vector_type;
+  };
+
 
   template <typename PT, typename SUBI>
   struct svrt_ir<PT, SUBI, abstract_sparse> {
