@@ -11,7 +11,7 @@ print TMPF "LY = 1.0;\n";
 print TMPF "LZ = 1.0;\n";
 print TMPF "MESH_TYPE = 0;\n";
 print TMPF "NX = 10;\n";
-print TMPF "NB_POINTS = 1000;\n";
+print TMPF "NB_POINTS = 100;\n";
 print TMPF "BASE = 10;\n";
 print TMPF "\n\n";
 close(TMPF);
@@ -27,7 +27,7 @@ while (<F>) {
     print $_, <F>;
   }
 }
+close(F);
+if ($?) { `rm -f $tmp`; exit(1); }
 if ($er == 1) { `rm -f $tmp`; exit(1); }
-`./geo_trans_inv $tmp`;
-`rm -f $tmp`; 
-if ($?) { exit(1); }
+`rm -f $tmp`;
