@@ -10,6 +10,6 @@ while (<F>) {
   }
 
 }
+close(F); if ($?) { exit(1); }
 if ($er == 1) { exit(1); }
-`./test_tree_sorted`;
-if ($?) { exit(1); }
+
